#ifndef _EFL_NETWORK_CONNECTOR_EO_H_
#define _EFL_NETWORK_CONNECTOR_EO_H_

#ifndef _EFL_NETWORK_CONNECTOR_EO_CLASS_TYPE
#define _EFL_NETWORK_CONNECTOR_EO_CLASS_TYPE

typedef Eo Efl_Network_Connector;

#endif

#ifndef _EFL_NETWORK_CONNECTOR_EO_TYPES
#define _EFL_NETWORK_CONNECTOR_EO_TYPES


#endif
/** Efl network connector class
 *
 * @ingroup Efl_Network_Connector
 */
#define EFL_NETWORK_CONNECTOR_CLASS efl_network_connector_class_get()

EWAPI const Eo_Class *efl_network_connector_class_get(void);


#endif
